@@ -2,4 +2,5 @@
 utils::globalVariables(c(".", "bin.type", "complete.cases", "dist.b", "dist.g", "glm", "iv.b", "nb", "ng", "no",
 			 "pct", "predict", "sb", "sg", "woe", "combn", "cor", "cutree", "dist", "group", "label",
 			 "label.y", "pchisq", "pnorm", "xtabs", "as.dist", "reg.tree", "segment", "mpred",
-			 "nb.obs", "nb.mod", "dr.mod", "dr.obs", "amse", "as.formula", "auc", "db.vld", "rmse"))
+			 "nb.obs", "nb.mod", "dr.mod", "dr.obs", "amse", "as.formula", "auc", "db.vld", "rmse", "bin",
+			 "n.base", "n.target"))
